#[repr(transparent)]pub struct Content {
inner: TypedObjectRef<Content, <Content as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A view displaying the selected content in the sidebar.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Content, <Content as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Content
impl Content
Sourcepub fn set_session<'a>(
&self,
value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_session<'a>( &self, value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>, )
The current session.
Sourcepub fn only_view(&self) -> <Cell<bool> as Property>::Value
pub fn only_view(&self) -> <Cell<bool> as Property>::Value
Whether this is the only visible view, i.e. there is no sidebar.
Sourcepub fn set_only_view<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_only_view<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this is the only visible view, i.e. there is no sidebar.
Sourcepub fn set_item<'a>(
&self,
value: Option<impl Borrow<<<BoundObject<Object> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_item<'a>( &self, value: Option<impl Borrow<<<BoundObject<Object> as Property>::Value as HasParamSpec>::SetValue>>, )
The item currently displayed.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_only_view_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_only_view_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the only-view property
Sourcepub fn connect_item_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the item property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_only_view(&self)
pub fn notify_only_view(&self)
Notify listeners of a change in the only-view property
Sourcepub fn notify_item(&self)
pub fn notify_item(&self)
Notify listeners of a change in the item property